:mod:`stix.exploit_target` Module
==================================

.. module:: stix.exploit_target

Overview
--------

The :mod:`stix.exploit_target` module implements :class:`.ExploitTarget`.

This denotes the specific vulnerability, weakness, or software configuration
that creates a security risk.


Documentation Resources
~~~~~~~~~~~~~~~~~~~~~~~

* `Exploit Target Data Model <https://stixproject.github.io/data-model/1.2/et/ExploitTargetType/>`_
* `Exploit Target Idioms <https://stixproject.github.io/documentation/idioms/cve/>`_

Classes
-------

.. autoclass:: ExploitTarget
    :show-inheritance:
    :members: add_configuration, add_description, add_short_description,
        add_vulnerability, add_weakness, configuration, description, descriptions,
        find, handling, id_, idref, information_source, short_description,
        short_descriptions, timestamp, title, to_dict, to_json, to_obj, version,
        vulnerabilities, walk, weaknesses

.. autoclass:: PotentialCOAs
    :show-inheritance:
    :members:

.. autoclass:: RelatedExploitTargets
    :show-inheritance:
    :members:
